#ifndef NT2_INCLUDE_FUNCTIONS_CONV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CONV_HPP_INCLUDED

#include <nt2/polynom/include/functions/conv.hpp>

#endif
